@@ -1,4 +1,4 @@
-`setminus` <-
+setminus <-
 function (A, B) 
 {
     res <- A[((A %in% B) == FALSE)]
